@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 use base qw(Exporter);
 
-our $VERSION = '1.004001';
+our $VERSION = '1.004004';
 $VERSION =~ tr/_//d;
 
 sub _choose_json_module {
@@ -57,9 +57,9 @@ sub is_bool {
   die 'is_bool is not a method' if $_[1];
 
   Scalar::Util::blessed($_[0])
-    and ($_[0]->isa('JSON::XS::Boolean')
+    and ($_[0]->isa('JSON::PP::Boolean')
       or $_[0]->isa('Cpanel::JSON::XS::Boolean')
-      or $_[0]->isa('JSON::PP::Boolean'));
+      or $_[0]->isa('JSON::XS::Boolean'));
 }
 
 # (mostly) CopyPasta from JSON.pm version 2.90
@@ -121,7 +121,8 @@ JSON::MaybeXS - Use L<Cpanel::JSON::XS> with a fallback to L<JSON::XS> and L<JSO
 =head1 DESCRIPTION
 
 This module first checks to see if either L<Cpanel::JSON::XS> or
-L<JSON::XS> is already loaded, in which case it uses that module. Otherwise
+L<JSON::XS> (at at least version 3.0)
+is already loaded, in which case it uses that module. Otherwise
 it tries to load L<Cpanel::JSON::XS>, then L<JSON::XS>, then L<JSON::PP>
 in order, and either uses the first module it finds or throws an error.
 
